@@ -93,7 +93,7 @@ class Almoststatic():
             config['config'] = {}
         self.content = config['config'].get("content", self.content)
         self.templates = config['config'].get("templates", self.templates)
-        self.templ_name = config['config'].get("template", self.templ_name)
+        self.templ_name = config['config'].get("templ_name", self.templ_name)
         self.pages = config['config'].get("pages", self.pages)
         self.media = config['config'].get("media", self.media)
         self.static_url = config['config'].get("static_url", self.static_url)
@@ -126,6 +126,8 @@ class Almoststatic():
 
         # functions addedd to templates
         self.vars['enum_list'] = enum_list
+        self.vars['iif'] = iif
+        self.vars['if_in'] = if_in
         self.vars['get_markdown'] = get_markdown
         self.vars['get_media'] = self.get_media
         self.vars['include'] = self._import_file
@@ -522,7 +524,7 @@ def enum_list(list_to_enum):
     Args:
         list_to_enum (list): the list to enumerate
     Returns:
-        tupla: the enumerated list
+        tuple: the enumerated list
     """
     return enumerate(list_to_enum)
 
@@ -538,6 +540,41 @@ def get_markdown(text):
     return markdown.markdown(text, extensions=['tables'])
 
 
+def iif(condition, if_true, if_false=""):
+    """Inline if shortcode
+    try: iif(1==1, "Ok", "No")
+
+    Args:
+        condition (bool): condition to test
+        if_true (any): value to return if condition is true
+        if_false (any): value to return if condition is false
+    Returns:
+        any: the result
+    """
+    if condition:
+        return if_true
+    return if_false
+
+
+def if_in(value, iterable, if_not=""):
+    """Inline check for inclusion.
+    try: ifin('a', ['a','b','c'], 'd')
+
+    Args:
+        value (any): value to check
+        iterable (iterable): iterable to search for value
+        if_not (any): value to return if not found
+
+    Returns:
+        any: the result
+    """
+    if not iterable:
+        iterable = []
+    if value in iterable:
+        return value
+    return if_not
+
+
 def _json_date_encoder(value):
     """encoder for json dumps of dates"""
     if isinstance(value, datetime.datetime):
